==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/authorization/entity/MapResourceServerEntityFields.java <==
package org.keycloak.models.map.authorization.entity;
public enum MapResourceServerEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.authorization.entity.MapResourceServerEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e) {
            return (String) e.getId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e, T value) {
            e.setId((String) value);
        }
    },
    ALLOW_REMOTE_RESOURCE_MANAGEMENT {
        public static final String FIELD_NAME = "AllowRemoteResourceManagement";
        public static final String FIELD_NAME_DASHED = "allow-remote-resource-management";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e, T value) {
            e.setAllowRemoteResourceManagement((Boolean) value);
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e) {
            return (Boolean) e.isAllowRemoteResourceManagement();
        }
    },
    CLIENT_ID {
        public static final String FIELD_NAME = "ClientId";
        public static final String FIELD_NAME_DASHED = "client-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e, T value) {
            e.setClientId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e) {
            return (String) e.getClientId();
        }
    },
    DECISION_STRATEGY {
        public static final String FIELD_NAME = "DecisionStrategy";
        public static final String FIELD_NAME_DASHED = "decision-strategy";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return org.keycloak.representations.idm.authorization.DecisionStrategy.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e, T value) {
            e.setDecisionStrategy((org.keycloak.representations.idm.authorization.DecisionStrategy) value);
        }
        @SuppressWarnings("unchecked") @Override public org.keycloak.representations.idm.authorization.DecisionStrategy get(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e) {
            return (org.keycloak.representations.idm.authorization.DecisionStrategy) e.getDecisionStrategy();
        }
    },
    POLICY_ENFORCEMENT_MODE {
        public static final String FIELD_NAME = "PolicyEnforcementMode";
        public static final String FIELD_NAME_DASHED = "policy-enforcement-mode";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return org.keycloak.representations.idm.authorization.PolicyEnforcementMode.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public org.keycloak.representations.idm.authorization.PolicyEnforcementMode get(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e) {
            return (org.keycloak.representations.idm.authorization.PolicyEnforcementMode) e.getPolicyEnforcementMode();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e, T value) {
            e.setPolicyEnforcementMode((org.keycloak.representations.idm.authorization.PolicyEnforcementMode) value);
        }
    },
    REALM_ID {
        public static final String FIELD_NAME = "RealmId";
        public static final String FIELD_NAME_DASHED = "realm-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e, T value) {
            e.setRealmId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e) {
            return (String) e.getRealmId();
        }
    },
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/authorization/entity/MapResourceServerEntityFields.java <==
package org.keycloak.models.map.authorization.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public enum MapResourceServerEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.authorization.entity.MapResourceServerEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        public static final String FIELD_NAME_CAMEL_CASE = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e, T value) {
            e.setId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e) {
            return (String) e.getId();
        }
    },
    ALLOW_REMOTE_RESOURCE_MANAGEMENT {
        public static final String FIELD_NAME = "AllowRemoteResourceManagement";
        public static final String FIELD_NAME_DASHED = "allow-remote-resource-management";
        public static final String FIELD_NAME_CAMEL_CASE = "allowRemoteResourceManagement";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e, T value) {
            e.setAllowRemoteResourceManagement((Boolean) value);
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e) {
            return (Boolean) e.isAllowRemoteResourceManagement();
        }
    },
    CLIENT_ID {
        public static final String FIELD_NAME = "ClientId";
        public static final String FIELD_NAME_DASHED = "client-id";
        public static final String FIELD_NAME_CAMEL_CASE = "clientId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e) {
            return (String) e.getClientId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e, T value) {
            e.setClientId((String) value);
        }
    },
    DECISION_STRATEGY {
        public static final String FIELD_NAME = "DecisionStrategy";
        public static final String FIELD_NAME_DASHED = "decision-strategy";
        public static final String FIELD_NAME_CAMEL_CASE = "decisionStrategy";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return org.keycloak.representations.idm.authorization.DecisionStrategy.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public org.keycloak.representations.idm.authorization.DecisionStrategy get(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e) {
            return (org.keycloak.representations.idm.authorization.DecisionStrategy) e.getDecisionStrategy();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e, T value) {
            e.setDecisionStrategy((org.keycloak.representations.idm.authorization.DecisionStrategy) value);
        }
    },
    POLICY_ENFORCEMENT_MODE {
        public static final String FIELD_NAME = "PolicyEnforcementMode";
        public static final String FIELD_NAME_DASHED = "policy-enforcement-mode";
        public static final String FIELD_NAME_CAMEL_CASE = "policyEnforcementMode";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return org.keycloak.representations.idm.authorization.PolicyEnforcementMode.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e, T value) {
            e.setPolicyEnforcementMode((org.keycloak.representations.idm.authorization.PolicyEnforcementMode) value);
        }
        @SuppressWarnings("unchecked") @Override public org.keycloak.representations.idm.authorization.PolicyEnforcementMode get(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e) {
            return (org.keycloak.representations.idm.authorization.PolicyEnforcementMode) e.getPolicyEnforcementMode();
        }
    },
    REALM_ID {
        public static final String FIELD_NAME = "RealmId";
        public static final String FIELD_NAME_DASHED = "realm-id";
        public static final String FIELD_NAME_CAMEL_CASE = "realmId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e) {
            return (String) e.getRealmId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceServerEntity e, T value) {
            e.setRealmId((String) value);
        }
    },
}
